<?php

if (!function_exists('ShutdownHandler') && !function_exists('ErrorHandler')) {
    if (getenv('APPLICATION_ENV') == 'dev') {
        ini_set('display_errors', 'On');
        ini_set('html_errors', 0);

        error_reporting(E_ERROR | E_WARNING | E_PARSE);
    } else {
        error_reporting(E_ERROR);
    }

    function ShutdownHandler()
    {
        if (@is_array($error = @error_get_last())) {
            return (@call_user_func_array('ErrorHandler', $error));
        };

        return (TRUE);
    };

    register_shutdown_function('ShutdownHandler');

    function ErrorHandler($type, $message, $file, $line)
    {
        $_ERRORS = array(
            0x0001 => 'E_ERROR',
            0x0002 => 'E_WARNING',
            0x0004 => 'E_PARSE',
            0x0008 => 'E_NOTICE',
            0x0010 => 'E_CORE_ERROR',
            0x0020 => 'E_CORE_WARNING',
            0x0040 => 'E_COMPILE_ERROR',
            0x0080 => 'E_COMPILE_WARNING',
            0x0100 => 'E_USER_ERROR',
            0x0200 => 'E_USER_WARNING',
            0x0400 => 'E_USER_NOTICE',
            0x0800 => 'E_STRICT',
            0x1000 => 'E_RECOVERABLE_ERROR',
            0x2000 => 'E_DEPRECATED',
            0x4000 => 'E_USER_DEPRECATED'
        );

        if (!@is_string($name = @array_search($type, @array_flip($_ERRORS)))) {
            $name = 'E_UNKNOWN';
        };

        if (in_array($name, array(
            'E_NOTICE',
            'E_USER_NOTICE',
            'E_STRICT',
            'E_DEPRECATED',
            'E_USER_DEPRECATED',
        ))) {
            return (TRUE);
        }

        if (defined('PATH_site') && stripos($file, realpath(PATH_site . 'typo3')) !== false && in_array($name, array(
            'E_WARNING',
            'E_CORE_WARNING',
        ))) {
            return (TRUE);
        }

        $errorMessage = @sprintf('%s Error in file "%s" at line %d: %s' . "\n", $name, $file, $line, $message);
        if (getenv('APPLICATION_ENV') == 'dev' || !getenv('ERROR_MAIL')) {
            return (print('<pre>' . $errorMessage . '</pre>'));
        } else {
            if (in_array($name, array(
                'E_ERROR',
                'E_PARSE',
                'E_CORE_ERROR',
                'E_COMPILE_ERROR',
                'E_USER_ERROR',
                'E_RECOVERABLE_ERROR',
            ))) {
                file_put_contents(PATH_site . 'typo3temp/error.log', date('d.m.Y H:i:s') . ' - ' . $errorMessage . "\n", FILE_APPEND | LOCK_EX);
                $errorMsgFile = PATH_site . 'typo3temp/Cache/Code/cache_core/error_' . md5($errorMessage) . '.lock';
                if (!file_exists($errorMsgFile) || filemtime($errorMsgFile) < (time() - 60*60)) {
                    file_put_contents($errorMsgFile, $errorMessage, LOCK_EX);

                    $domain = $_SERVER['HTTP_HOST'];
                    mail(getenv('ERROR_MAIL'), 'TYPO3 Error' . ($domain ? ' | ' . $domain : ''), $errorMessage,
                        'From: dev@imia.de' . "\r\n" .
                        'Reply-To: dev@imia.de' . "\r\n" .
                        'X-Mailer: PHP/' . phpversion());
                }
            }

            return (TRUE);
        }
    };

    $GLOBALS['oldErrorHandler'] = set_error_handler('ErrorHandler');
}